#
# Copyright 2020 Xilinx, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#!/bin/bash
# This script accepts an 8-bit, YUV420, pre-encoded h264 file and will send the encoded h.264 output to /tmp/xil_ftrt_xcode.mp4 at a rate of 8Mbps.
# This use case is optimized for "faster than realtime"; that is, processing a whole clip faster than the human eye would watch it.

# You may change the target codec to HEVC by changing:
#     the h264parse plugin to h265parse plugin for encoding into HEVC

if [ $# -lt 1 ]; then
     echo -e "\e[01;31m"Note : Script did not run. Check the below help on how to run the script and arguments to be given"\e[0m"
     echo "$0 <Input H264 file>"
     echo "" 
     echo "As per VCU procceing capacity, below are the input limitations."
     echo "Ex: $0 Test_1080p30.h264"
     exit 1
fi

#check if the input stream is compatiable with this script
codec_type=`gst-discoverer-1.0 $1 | grep "video #" | cut -d":" -f2 | awk '{print $1;}'`
echo $codec_type
if [ "$codec_type" != "H.264" ]; then
    echo "This script only supports H.264 input"
    exit -1
fi

pipe=" -v"
echo "Script is running for filesink ............"
pipe="filesrc location=$1 
	! parsebin
	! h264parse 
	! ama_h264dec device=0 
	! queue 
	! ama_h264enc bitrate=8000000
	! h264parse 
	! video/x-h264 
	! qtmux 
	! fpsdisplaysink video-sink=\"filesink location=/tmp/xil_ftrt_xcode.mp4 \" text-overlay=false sync=false "$pipe
pipe="gst-launch-1.0 "$pipe
$pipe
